# navallist

Intelligent Departure Checklist

Session ID (Trip Name)
Your Name

### Your Recent Trips

# Loading...

## Trip Report

## Settings

Hide Checked Items

Completed items will be removed from the list.

graphic_eq

Listening...

### Join Trip

Scan to join this session

### All Checks Complete!

Would you like to mark the trip status as Ready?

## Item Info

#### photo_camera Photo Requirement

refresh
1 / 1

### Assign Item